# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_signals_list_response_meta_page import (
        SecurityMonitoringSignalsListResponseMetaPage,
    )


class SecurityMonitoringSignalsListResponseMeta(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_signals_list_response_meta_page import (
            SecurityMonitoringSignalsListResponseMetaPage,
        )

        return {
            "page": (SecurityMonitoringSignalsListResponseMetaPage,),
        }

    attribute_map = {
        "page": "page",
    }

    def __init__(self_, page: Union[SecurityMonitoringSignalsListResponseMetaPage, UnsetType] = unset, **kwargs):
        """
        Meta attributes.

        :param page: Paging attributes.
        :type page: SecurityMonitoringSignalsListResponseMetaPage, optional
        """
        if page is not unset:
            kwargs["page"] = page
        super().__init__(kwargs)



import pytest

from datadog_api_client.api_client import ApiClient
from datadog_api_client.configuration import Configuration
from datadog_api_client.exceptions import ApiValueError
from datadog_api_client.v1.api import metrics_api


def test_invalid_header():
    configuration = Configuration()
    configuration.api_key["apiKeyAuth"] = None

    with ApiClient(configuration) as api_client:
        api_instance = metrics_api.MetricsApi(api_client)
        with pytest.raises(ApiValueError):
            api_instance.get_metric_metadata("some_metric")



"""
Get a quick list of logs returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_api import LogsApi
from datetime import datetime
from dateutil.tz import tzoffset

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsApi(api_client)
    response = api_instance.list_logs_get(
        filter_query="datadog-agent",
        filter_index="main",
        filter_from=datetime(2020, 9, 17, 11, 48, 36, tzinfo=tzoffset(None, 3600)),
        filter_to=datetime(2020, 9, 17, 12, 48, 36, tzinfo=tzoffset(None, 3600)),
        page_limit=5,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MetricTagConfigurationMetricTypes(ModelSimple):
    """
    The metric's type.

    :param value: If omitted defaults to "gauge". Must be one of ["gauge", "count", "rate", "distribution"].
    :type value: str
    """

    allowed_values = {
        "gauge",
        "count",
        "rate",
        "distribution",
    }
    GAUGE: ClassVar["MetricTagConfigurationMetricTypes"]
    COUNT: ClassVar["MetricTagConfigurationMetricTypes"]
    RATE: ClassVar["MetricTagConfigurationMetricTypes"]
    DISTRIBUTION: ClassVar["MetricTagConfigurationMetricTypes"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MetricTagConfigurationMetricTypes.GAUGE = MetricTagConfigurationMetricTypes("gauge")
MetricTagConfigurationMetricTypes.COUNT = MetricTagConfigurationMetricTypes("count")
MetricTagConfigurationMetricTypes.RATE = MetricTagConfigurationMetricTypes("rate")
MetricTagConfigurationMetricTypes.DISTRIBUTION = MetricTagConfigurationMetricTypes("distribution")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class TimeseriesWidgetExpressionAlias(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "alias_name": (str,),
            "expression": (str,),
        }

    attribute_map = {
        "alias_name": "alias_name",
        "expression": "expression",
    }

    def __init__(self_, expression: str, alias_name: Union[str, UnsetType] = unset, **kwargs):
        """
        Define an expression alias.

        :param alias_name: Expression alias.
        :type alias_name: str, optional

        :param expression: Expression name.
        :type expression: str
        """
        if alias_name is not unset:
            kwargs["alias_name"] = alias_name
        super().__init__(kwargs)

        self_.expression = expression



"""
Get a custom variable returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrationApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = WebhooksIntegrationApi(api_client)
    response = api_instance.get_webhooks_integration_custom_variable(
        custom_variable_name="custom_variable_name",
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup


class MonitorState(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup

        return {
            "groups": ({str: (MonitorStateGroup,)},),
        }

    attribute_map = {
        "groups": "groups",
    }

    def __init__(self_, groups: Union[Dict[str, MonitorStateGroup], UnsetType] = unset, **kwargs):
        """
        Wrapper object with the different monitor states.

        :param groups: Dictionary where the keys are groups (comma separated lists of tags) and the values are
            the list of groups your monitor is broken down on.
        :type groups: {str: (MonitorStateGroup,)}, optional
        """
        if groups is not unset:
            kwargs["groups"] = groups
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ServiceDefinitionV1Info(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "dd_service": (str,),
            "description": (str,),
            "display_name": (str,),
            "service_tier": (str,),
        }

    attribute_map = {
        "dd_service": "dd-service",
        "description": "description",
        "display_name": "display-name",
        "service_tier": "service-tier",
    }

    def __init__(
        self_,
        dd_service: str,
        description: Union[str, UnsetType] = unset,
        display_name: Union[str, UnsetType] = unset,
        service_tier: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Basic information about a service.

        :param dd_service: Unique identifier of the service. Must be unique across all services and is used to match with a service in Datadog.
        :type dd_service: str

        :param description: A short description of the service.
        :type description: str, optional

        :param display_name: A friendly name of the service.
        :type display_name: str, optional

        :param service_tier: Service tier.
        :type service_tier: str, optional
        """
        if description is not unset:
            kwargs["description"] = description
        if display_name is not unset:
            kwargs["display_name"] = display_name
        if service_tier is not unset:
            kwargs["service_tier"] = service_tier
        super().__init__(kwargs)

        self_.dd_service = dd_service



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.search_slo_response_data_attributes_facets import (
        SearchSLOResponseDataAttributesFacets,
    )
    from datadog_api_client.v1.model.search_service_level_objective import SearchServiceLevelObjective


class SearchSLOResponseDataAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.search_slo_response_data_attributes_facets import (
            SearchSLOResponseDataAttributesFacets,
        )
        from datadog_api_client.v1.model.search_service_level_objective import SearchServiceLevelObjective

        return {
            "facets": (SearchSLOResponseDataAttributesFacets,),
            "slos": ([SearchServiceLevelObjective],),
        }

    attribute_map = {
        "facets": "facets",
        "slos": "slos",
    }

    def __init__(
        self_,
        facets: Union[SearchSLOResponseDataAttributesFacets, UnsetType] = unset,
        slos: Union[List[SearchServiceLevelObjective], UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes

        :param facets: Facets
        :type facets: SearchSLOResponseDataAttributesFacets, optional

        :param slos: SLOs
        :type slos: [SearchServiceLevelObjective], optional
        """
        if facets is not unset:
            kwargs["facets"] = facets
        if slos is not unset:
            kwargs["slos"] = slos
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class OrganizationAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "created_at": (datetime,),
            "description": (str,),
            "disabled": (bool,),
            "modified_at": (datetime,),
            "name": (str,),
            "public_id": (str,),
            "sharing": (str,),
            "url": (str,),
        }

    attribute_map = {
        "created_at": "created_at",
        "description": "description",
        "disabled": "disabled",
        "modified_at": "modified_at",
        "name": "name",
        "public_id": "public_id",
        "sharing": "sharing",
        "url": "url",
    }

    def __init__(
        self_,
        created_at: Union[datetime, UnsetType] = unset,
        description: Union[str, UnsetType] = unset,
        disabled: Union[bool, UnsetType] = unset,
        modified_at: Union[datetime, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        sharing: Union[str, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of the organization.

        :param created_at: Creation time of the organization.
        :type created_at: datetime, optional

        :param description: Description of the organization.
        :type description: str, optional

        :param disabled: Whether or not the organization is disabled.
        :type disabled: bool, optional

        :param modified_at: Time of last organization modification.
        :type modified_at: datetime, optional

        :param name: Name of the organization.
        :type name: str, optional

        :param public_id: Public ID of the organization.
        :type public_id: str, optional

        :param sharing: Sharing type of the organization.
        :type sharing: str, optional

        :param url: URL of the site that this organization exists at.
        :type url: str, optional
        """
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if description is not unset:
            kwargs["description"] = description
        if disabled is not unset:
            kwargs["disabled"] = disabled
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if name is not unset:
            kwargs["name"] = name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if sharing is not unset:
            kwargs["sharing"] = sharing
        if url is not unset:
            kwargs["url"] = url
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_by_retention_orgs import LogsByRetentionOrgs
    from datadog_api_client.v1.model.logs_retention_agg_sum_usage import LogsRetentionAggSumUsage
    from datadog_api_client.v1.model.logs_by_retention_monthly_usage import LogsByRetentionMonthlyUsage


class LogsByRetention(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_by_retention_orgs import LogsByRetentionOrgs
        from datadog_api_client.v1.model.logs_retention_agg_sum_usage import LogsRetentionAggSumUsage
        from datadog_api_client.v1.model.logs_by_retention_monthly_usage import LogsByRetentionMonthlyUsage

        return {
            "orgs": (LogsByRetentionOrgs,),
            "usage": ([LogsRetentionAggSumUsage],),
            "usage_by_month": (LogsByRetentionMonthlyUsage,),
        }

    attribute_map = {
        "orgs": "orgs",
        "usage": "usage",
        "usage_by_month": "usage_by_month",
    }

    def __init__(
        self_,
        orgs: Union[LogsByRetentionOrgs, UnsetType] = unset,
        usage: Union[List[LogsRetentionAggSumUsage], UnsetType] = unset,
        usage_by_month: Union[LogsByRetentionMonthlyUsage, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing logs usage data broken down by retention period.

        :param orgs: Indexed logs usage summary for each organization for each retention period with usage.
        :type orgs: LogsByRetentionOrgs, optional

        :param usage: Aggregated index logs usage for each retention period with usage.
        :type usage: [LogsRetentionAggSumUsage], optional

        :param usage_by_month: Object containing a summary of indexed logs usage by retention period for a single month.
        :type usage_by_month: LogsByRetentionMonthlyUsage, optional
        """
        if orgs is not unset:
            kwargs["orgs"] = orgs
        if usage is not unset:
            kwargs["usage"] = usage
        if usage_by_month is not unset:
            kwargs["usage_by_month"] = usage_by_month
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringSignalState(ModelSimple):
    """
    The new triage state of the signal.

    :param value: Must be one of ["open", "archived", "under_review"].
    :type value: str
    """

    allowed_values = {
        "open",
        "archived",
        "under_review",
    }
    OPEN: ClassVar["SecurityMonitoringSignalState"]
    ARCHIVED: ClassVar["SecurityMonitoringSignalState"]
    UNDER_REVIEW: ClassVar["SecurityMonitoringSignalState"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringSignalState.OPEN = SecurityMonitoringSignalState("open")
SecurityMonitoringSignalState.ARCHIVED = SecurityMonitoringSignalState("archived")
SecurityMonitoringSignalState.UNDER_REVIEW = SecurityMonitoringSignalState("under_review")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostMetaInstallMethod(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "installer_version": (str,),
            "tool": (str,),
            "tool_version": (str,),
        }

    attribute_map = {
        "installer_version": "installer_version",
        "tool": "tool",
        "tool_version": "tool_version",
    }

    def __init__(
        self_,
        installer_version: Union[str, UnsetType] = unset,
        tool: Union[str, UnsetType] = unset,
        tool_version: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Agent install method.

        :param installer_version: The installer version.
        :type installer_version: str, optional

        :param tool: Tool used to install the agent.
        :type tool: str, optional

        :param tool_version: The tool version.
        :type tool_version: str, optional
        """
        if installer_version is not unset:
            kwargs["installer_version"] = installer_version
        if tool is not unset:
            kwargs["tool"] = tool
        if tool_version is not unset:
            kwargs["tool_version"] = tool_version
        super().__init__(kwargs)



"""
Post an event returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.events_api import EventsApi
from datadog_api_client.v1.model.event_create_request import EventCreateRequest

body = EventCreateRequest(
    title="Example-Post_an_event_returns_OK_response",
    text="A text message.",
    tags=[
        "test:ExamplePostaneventreturnsOKresponse",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = EventsApi(api_client)
    response = api_instance.create_event(body=body)

    print(response)



"""
Bulk Delete SLO Timeframes returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objectives_api import ServiceLevelObjectivesApi
from datadog_api_client.v1.model.slo_bulk_delete import SLOBulkDelete
from datadog_api_client.v1.model.slo_timeframe import SLOTimeframe

body = SLOBulkDelete(
    id1=[
        SLOTimeframe.SEVEN_DAYS,
        SLOTimeframe.THIRTY_DAYS,
    ],
    id2=[
        SLOTimeframe.SEVEN_DAYS,
        SLOTimeframe.THIRTY_DAYS,
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectivesApi(api_client)
    response = api_instance.delete_slo_timeframe_in_bulk(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.formula_and_function_event_query_definition_compute import (
        FormulaAndFunctionEventQueryDefinitionCompute,
    )
    from datadog_api_client.v1.model.formula_and_function_events_data_source import FormulaAndFunctionEventsDataSource
    from datadog_api_client.v1.model.formula_and_function_event_query_group_by import (
        FormulaAndFunctionEventQueryGroupBy,
    )
    from datadog_api_client.v1.model.formula_and_function_event_query_definition_search import (
        FormulaAndFunctionEventQueryDefinitionSearch,
    )


class FormulaAndFunctionEventQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.formula_and_function_event_query_definition_compute import (
            FormulaAndFunctionEventQueryDefinitionCompute,
        )
        from datadog_api_client.v1.model.formula_and_function_events_data_source import (
            FormulaAndFunctionEventsDataSource,
        )
        from datadog_api_client.v1.model.formula_and_function_event_query_group_by import (
            FormulaAndFunctionEventQueryGroupBy,
        )
        from datadog_api_client.v1.model.formula_and_function_event_query_definition_search import (
            FormulaAndFunctionEventQueryDefinitionSearch,
        )

        return {
            "compute": (FormulaAndFunctionEventQueryDefinitionCompute,),
            "data_source": (FormulaAndFunctionEventsDataSource,),
            "group_by": ([FormulaAndFunctionEventQueryGroupBy],),
            "indexes": ([str],),
            "name": (str,),
            "search": (FormulaAndFunctionEventQueryDefinitionSearch,),
            "storage": (str,),
        }

    attribute_map = {
        "compute": "compute",
        "data_source": "data_source",
        "group_by": "group_by",
        "indexes": "indexes",
        "name": "name",
        "search": "search",
        "storage": "storage",
    }

    def __init__(
        self_,
        compute: FormulaAndFunctionEventQueryDefinitionCompute,
        data_source: FormulaAndFunctionEventsDataSource,
        name: str,
        group_by: Union[List[FormulaAndFunctionEventQueryGroupBy], UnsetType] = unset,
        indexes: Union[List[str], UnsetType] = unset,
        search: Union[FormulaAndFunctionEventQueryDefinitionSearch, UnsetType] = unset,
        storage: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A formula and functions events query.

        :param compute: Compute options.
        :type compute: FormulaAndFunctionEventQueryDefinitionCompute

        :param data_source: Data source for event platform-based queries.
        :type data_source: FormulaAndFunctionEventsDataSource

        :param group_by: Group by options.
        :type group_by: [FormulaAndFunctionEventQueryGroupBy], optional

        :param indexes: An array of index names to query in the stream. Omit or use ``[]`` to query all indexes at once.
        :type indexes: [str], optional

        :param name: Name of the query for use in formulas.
        :type name: str

        :param search: Search options.
        :type search: FormulaAndFunctionEventQueryDefinitionSearch, optional

        :param storage: Option for storage location. Feature in Private Beta.
        :type storage: str, optional
        """
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if indexes is not unset:
            kwargs["indexes"] = indexes
        if search is not unset:
            kwargs["search"] = search
        if storage is not unset:
            kwargs["storage"] = storage
        super().__init__(kwargs)

        self_.compute = compute
        self_.data_source = data_source
        self_.name = name



"""
Edit a private location returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
from datadog_api_client.v1.model.synthetics_private_location_metadata import SyntheticsPrivateLocationMetadata
from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles

body = SyntheticsPrivateLocation(
    description="Description of private location",
    metadata=SyntheticsPrivateLocationMetadata(
        restricted_roles=SyntheticsRestrictedRoles(
            [
                "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            ]
        ),
    ),
    name="New private location",
    tags=[
        "team:front",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.update_private_location(location_id="location_id", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_horizontal_align import WidgetHorizontalAlign
    from datadog_api_client.v1.model.widget_margin import WidgetMargin
    from datadog_api_client.v1.model.widget_image_sizing import WidgetImageSizing
    from datadog_api_client.v1.model.image_widget_definition_type import ImageWidgetDefinitionType
    from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign


class ImageWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_horizontal_align import WidgetHorizontalAlign
        from datadog_api_client.v1.model.widget_margin import WidgetMargin
        from datadog_api_client.v1.model.widget_image_sizing import WidgetImageSizing
        from datadog_api_client.v1.model.image_widget_definition_type import ImageWidgetDefinitionType
        from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign

        return {
            "has_background": (bool,),
            "has_border": (bool,),
            "horizontal_align": (WidgetHorizontalAlign,),
            "margin": (WidgetMargin,),
            "sizing": (WidgetImageSizing,),
            "type": (ImageWidgetDefinitionType,),
            "url": (str,),
            "url_dark_theme": (str,),
            "vertical_align": (WidgetVerticalAlign,),
        }

    attribute_map = {
        "has_background": "has_background",
        "has_border": "has_border",
        "horizontal_align": "horizontal_align",
        "margin": "margin",
        "sizing": "sizing",
        "type": "type",
        "url": "url",
        "url_dark_theme": "url_dark_theme",
        "vertical_align": "vertical_align",
    }

    def __init__(
        self_,
        type: ImageWidgetDefinitionType,
        url: str,
        has_background: Union[bool, UnsetType] = unset,
        has_border: Union[bool, UnsetType] = unset,
        horizontal_align: Union[WidgetHorizontalAlign, UnsetType] = unset,
        margin: Union[WidgetMargin, UnsetType] = unset,
        sizing: Union[WidgetImageSizing, UnsetType] = unset,
        url_dark_theme: Union[str, UnsetType] = unset,
        vertical_align: Union[WidgetVerticalAlign, UnsetType] = unset,
        **kwargs,
    ):
        """
        The image widget allows you to embed an image on your dashboard. An image can be a PNG, JPG, or animated GIF. Only available on FREE layout dashboards.

        :param has_background: Whether to display a background or not.
        :type has_background: bool, optional

        :param has_border: Whether to display a border or not.
        :type has_border: bool, optional

        :param horizontal_align: Horizontal alignment.
        :type horizontal_align: WidgetHorizontalAlign, optional

        :param margin: Size of the margins around the image.
            **Note** : ``small`` and ``large`` values are deprecated.
        :type margin: WidgetMargin, optional

        :param sizing: How to size the image on the widget. The values are based on the image ``object-fit`` CSS properties.
            **Note** : ``zoom`` , ``fit`` and ``center`` values are deprecated.
        :type sizing: WidgetImageSizing, optional

        :param type: Type of the image widget.
        :type type: ImageWidgetDefinitionType

        :param url: URL of the image.
        :type url: str

        :param url_dark_theme: URL of the image in dark mode.
        :type url_dark_theme: str, optional

        :param vertical_align: Vertical alignment.
        :type vertical_align: WidgetVerticalAlign, optional
        """
        if has_background is not unset:
            kwargs["has_background"] = has_background
        if has_border is not unset:
            kwargs["has_border"] = has_border
        if horizontal_align is not unset:
            kwargs["horizontal_align"] = horizontal_align
        if margin is not unset:
            kwargs["margin"] = margin
        if sizing is not unset:
            kwargs["sizing"] = sizing
        if url_dark_theme is not unset:
            kwargs["url_dark_theme"] = url_dark_theme
        if vertical_align is not unset:
            kwargs["vertical_align"] = vertical_align
        super().__init__(kwargs)

        self_.type = type
        self_.url = url



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.pager_duty_service_name import PagerDutyServiceName
from datadog_api_client.v1.model.pager_duty_service import PagerDutyService
from datadog_api_client.v1.model.pager_duty_service_key import PagerDutyServiceKey


class PagerDutyIntegrationApi:
    """
    Configure your `Datadog-PagerDuty integration <https://docs.datadoghq.com/integrations/pagerduty/>`_
    directly through the Datadog API.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_pager_duty_integration_service_endpoint = _Endpoint(
            settings={
                "response_type": (PagerDutyServiceName,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/pagerduty/configuration/services",
                "operation_id": "create_pager_duty_integration_service",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (PagerDutyService,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_pager_duty_integration_service_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/pagerduty/configuration/services/{service_name}",
                "operation_id": "delete_pager_duty_integration_service",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "service_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_name",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_pager_duty_integration_service_endpoint = _Endpoint(
            settings={
                "response_type": (PagerDutyServiceName,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/pagerduty/configuration/services/{service_name}",
                "operation_id": "get_pager_duty_integration_service",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "service_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_name",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_pager_duty_integration_service_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/pagerduty/configuration/services/{service_name}",
                "operation_id": "update_pager_duty_integration_service",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "service_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "service_name",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (PagerDutyServiceKey,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["*/*"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_pager_duty_integration_service(
        self,
        body: PagerDutyService,
    ) -> PagerDutyServiceName:
        """Create a new service object.

        Create a new service object in the PagerDuty integration.

        :param body: Create a new service object request body.
        :type body: PagerDutyService
        :rtype: PagerDutyServiceName
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_pager_duty_integration_service_endpoint.call_with_http_info(**kwargs)

    def delete_pager_duty_integration_service(
        self,
        service_name: str,
    ) -> None:
        """Delete a single service object.

        Delete a single service object in the Datadog-PagerDuty integration.

        :param service_name: The service name
        :type service_name: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_name"] = service_name

        return self._delete_pager_duty_integration_service_endpoint.call_with_http_info(**kwargs)

    def get_pager_duty_integration_service(
        self,
        service_name: str,
    ) -> PagerDutyServiceName:
        """Get a single service object.

        Get service name in the Datadog-PagerDuty integration.

        :param service_name: The service name.
        :type service_name: str
        :rtype: PagerDutyServiceName
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_name"] = service_name

        return self._get_pager_duty_integration_service_endpoint.call_with_http_info(**kwargs)

    def update_pager_duty_integration_service(
        self,
        service_name: str,
        body: PagerDutyServiceKey,
    ) -> None:
        """Update a single service object.

        Update a single service object in the Datadog-PagerDuty integration.

        :param service_name: The service name
        :type service_name: str
        :param body: Update an existing service object request body.
        :type body: PagerDutyServiceKey
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["service_name"] = service_name

        kwargs["body"] = body

        return self._update_pager_duty_integration_service_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ApiKey(ModelNormal):
    validations = {
        "key": {
            "max_length": 32,
            "min_length": 32,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "created": (str,),
            "created_by": (str,),
            "key": (str,),
            "name": (str,),
        }

    attribute_map = {
        "created": "created",
        "created_by": "created_by",
        "key": "key",
        "name": "name",
    }
    read_only_vars = {
        "created",
        "created_by",
        "key",
    }

    def __init__(
        self_,
        created: Union[str, UnsetType] = unset,
        created_by: Union[str, UnsetType] = unset,
        key: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Datadog API key.

        :param created: Date of creation of the API key.
        :type created: str, optional

        :param created_by: Datadog user handle that created the API key.
        :type created_by: str, optional

        :param key: API key.
        :type key: str, optional

        :param name: Name of your API key.
        :type name: str, optional
        """
        if created is not unset:
            kwargs["created"] = created
        if created_by is not unset:
            kwargs["created_by"] = created_by
        if key is not unset:
            kwargs["key"] = key
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)



"""
Create an Azure integration returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.azure_integration_api import AzureIntegrationApi
from datadog_api_client.v1.model.azure_account import AzureAccount

body = AzureAccount(
    automute=True,
    client_id="testc7f6-1234-5678-9101-3fcbf464test",
    client_secret="testingx./Sw*g/Y33t..R1cH+hScMDt",
    errors=[
        "*",
    ],
    host_filters="key:value,filter:example",
    new_client_id="new1c7f6-1234-5678-9101-3fcbf464test",
    new_tenant_name="new1c44-1234-5678-9101-cc00736ftest",
    tenant_name="testc44-1234-5678-9101-cc00736ftest",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AzureIntegrationApi(api_client)
    response = api_instance.create_azure_integration(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_archive_integration_azure import LogsArchiveIntegrationAzure
    from datadog_api_client.v2.model.logs_archive_destination_azure_type import LogsArchiveDestinationAzureType


class LogsArchiveDestinationAzure(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_archive_integration_azure import LogsArchiveIntegrationAzure
        from datadog_api_client.v2.model.logs_archive_destination_azure_type import LogsArchiveDestinationAzureType

        return {
            "container": (str,),
            "integration": (LogsArchiveIntegrationAzure,),
            "path": (str,),
            "region": (str,),
            "storage_account": (str,),
            "type": (LogsArchiveDestinationAzureType,),
        }

    attribute_map = {
        "container": "container",
        "integration": "integration",
        "path": "path",
        "region": "region",
        "storage_account": "storage_account",
        "type": "type",
    }

    def __init__(
        self_,
        container: str,
        integration: LogsArchiveIntegrationAzure,
        storage_account: str,
        type: LogsArchiveDestinationAzureType,
        path: Union[str, UnsetType] = unset,
        region: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The Azure archive destination.

        :param container: The container where the archive will be stored.
        :type container: str

        :param integration: The Azure archive's integration destination.
        :type integration: LogsArchiveIntegrationAzure

        :param path: The archive path.
        :type path: str, optional

        :param region: The region where the archive will be stored.
        :type region: str, optional

        :param storage_account: The associated storage account.
        :type storage_account: str

        :param type: Type of the Azure archive destination.
        :type type: LogsArchiveDestinationAzureType
        """
        if path is not unset:
            kwargs["path"] = path
        if region is not unset:
            kwargs["region"] = region
        super().__init__(kwargs)

        self_.container = container
        self_.integration = integration
        self_.storage_account = storage_account
        self_.type = type



"""
Create a webhooks integration returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrationApi
from datadog_api_client.v1.model.webhooks_integration import WebhooksIntegration

body = WebhooksIntegration(
    name="Example-Create_a_webhooks_integration_returns_OK_response",
    url="https://example.com/webhook",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = WebhooksIntegrationApi(api_client)
    response = api_instance.create_webhooks_integration(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class IPPrefixesWebhooks(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "prefixes_ipv4": ([str],),
            "prefixes_ipv6": ([str],),
        }

    attribute_map = {
        "prefixes_ipv4": "prefixes_ipv4",
        "prefixes_ipv6": "prefixes_ipv6",
    }

    def __init__(
        self_,
        prefixes_ipv4: Union[List[str], UnsetType] = unset,
        prefixes_ipv6: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Available prefix information for the Webhook endpoints.

        :param prefixes_ipv4: List of IPv4 prefixes.
        :type prefixes_ipv4: [str], optional

        :param prefixes_ipv6: List of IPv6 prefixes.
        :type prefixes_ipv6: [str], optional
        """
        if prefixes_ipv4 is not unset:
            kwargs["prefixes_ipv4"] = prefixes_ipv4
        if prefixes_ipv6 is not unset:
            kwargs["prefixes_ipv6"] = prefixes_ipv6
        super().__init__(kwargs)



"""
Update an existing incident service returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi
from datadog_api_client.v2.model.incident_service_type import IncidentServiceType
from datadog_api_client.v2.model.incident_service_update_attributes import IncidentServiceUpdateAttributes
from datadog_api_client.v2.model.incident_service_update_data import IncidentServiceUpdateData
from datadog_api_client.v2.model.incident_service_update_request import IncidentServiceUpdateRequest

# there is a valid "service" in the system
SERVICE_DATA_ATTRIBUTES_NAME = environ["SERVICE_DATA_ATTRIBUTES_NAME"]
SERVICE_DATA_ID = environ["SERVICE_DATA_ID"]

body = IncidentServiceUpdateRequest(
    data=IncidentServiceUpdateData(
        type=IncidentServiceType.SERVICES,
        attributes=IncidentServiceUpdateAttributes(
            name="service name-updated",
        ),
    ),
)

configuration = Configuration()
configuration.unstable_operations["update_incident_service"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentServicesApi(api_client)
    response = api_instance.update_incident_service(service_id=SERVICE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class CIAppQueryOptions(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "time_offset": (int,),
            "timezone": (str,),
        }

    attribute_map = {
        "time_offset": "time_offset",
        "timezone": "timezone",
    }

    def __init__(self_, time_offset: Union[int, UnsetType] = unset, timezone: Union[str, UnsetType] = unset, **kwargs):
        """
        Global query options that are used during the query.
        Only supply timezone or time offset, not both. Otherwise, the query fails.

        :param time_offset: The time offset (in seconds) to apply to the query.
        :type time_offset: int, optional

        :param timezone: The timezone can be specified as GMT, UTC, an offset from UTC (like UTC+1), or as a Timezone Database identifier (like America/New_York).
        :type timezone: str, optional
        """
        if time_offset is not unset:
            kwargs["time_offset"] = time_offset
        if timezone is not unset:
            kwargs["timezone"] = timezone
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
    from datadog_api_client.v2.model.roles_type import RolesType


class RoleClone(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
        from datadog_api_client.v2.model.roles_type import RolesType

        return {
            "attributes": (RoleCloneAttributes,),
            "type": (RolesType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "type": "type",
    }

    def __init__(self_, attributes: RoleCloneAttributes, type: RolesType, **kwargs):
        """
        Data for the clone role request.

        :param attributes: Attributes required to create a new role by cloning an existing one.
        :type attributes: RoleCloneAttributes

        :param type: Roles type.
        :type type: RolesType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.aws_logs_async_error import AWSLogsAsyncError


class AWSLogsAsyncResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.aws_logs_async_error import AWSLogsAsyncError

        return {
            "errors": ([AWSLogsAsyncError],),
            "status": (str,),
        }

    attribute_map = {
        "errors": "errors",
        "status": "status",
    }

    def __init__(
        self_,
        errors: Union[List[AWSLogsAsyncError], UnsetType] = unset,
        status: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A list of all Datadog-AWS logs integrations available in your Datadog organization.

        :param errors: List of errors.
        :type errors: [AWSLogsAsyncError], optional

        :param status: Status of the properties.
        :type status: str, optional
        """
        if errors is not unset:
            kwargs["errors"] = errors
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetMargin(ModelSimple):
    """
    Size of the margins around the image.
        **Note**: `small` and `large` values are deprecated.

    :param value: Must be one of ["sm", "md", "lg", "small", "large"].
    :type value: str
    """

    allowed_values = {
        "sm",
        "md",
        "lg",
        "small",
        "large",
    }
    SM: ClassVar["WidgetMargin"]
    MD: ClassVar["WidgetMargin"]
    LG: ClassVar["WidgetMargin"]
    SMALL: ClassVar["WidgetMargin"]
    LARGE: ClassVar["WidgetMargin"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetMargin.SM = WidgetMargin("sm")
WidgetMargin.MD = WidgetMargin("md")
WidgetMargin.LG = WidgetMargin("lg")
WidgetMargin.SMALL = WidgetMargin("small")
WidgetMargin.LARGE = WidgetMargin("large")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_metadata import MetricMetadata
    from datadog_api_client.v2.model.metric_point import MetricPoint
    from datadog_api_client.v2.model.metric_resource import MetricResource
    from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType


class MetricSeries(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_metadata import MetricMetadata
        from datadog_api_client.v2.model.metric_point import MetricPoint
        from datadog_api_client.v2.model.metric_resource import MetricResource
        from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType

        return {
            "interval": (int,),
            "metadata": (MetricMetadata,),
            "metric": (str,),
            "points": ([MetricPoint],),
            "resources": ([MetricResource],),
            "source_type_name": (str,),
            "tags": ([str],),
            "type": (MetricIntakeType,),
            "unit": (str,),
        }

    attribute_map = {
        "interval": "interval",
        "metadata": "metadata",
        "metric": "metric",
        "points": "points",
        "resources": "resources",
        "source_type_name": "source_type_name",
        "tags": "tags",
        "type": "type",
        "unit": "unit",
    }

    def __init__(
        self_,
        metric: str,
        points: List[MetricPoint],
        interval: Union[int, UnsetType] = unset,
        metadata: Union[MetricMetadata, UnsetType] = unset,
        resources: Union[List[MetricResource], UnsetType] = unset,
        source_type_name: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[MetricIntakeType, UnsetType] = unset,
        unit: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A metric to submit to Datadog.
        See `Datadog metrics <https://docs.datadoghq.com/developers/metrics/#custom-metrics-properties>`_.

        :param interval: If the type of the metric is rate or count, define the corresponding interval.
        :type interval: int, optional

        :param metadata: Metadata for the metric.
        :type metadata: MetricMetadata, optional

        :param metric: The name of the timeseries.
        :type metric: str

        :param points: Points relating to a metric. All points must be objects with timestamp and a scalar value (cannot be a string). Timestamps should be in POSIX time in seconds, and cannot be more than ten minutes in the future or more than one hour in the past.
        :type points: [MetricPoint]

        :param resources: A list of resources to associate with this metric.
        :type resources: [MetricResource], optional

        :param source_type_name: The source type name.
        :type source_type_name: str, optional

        :param tags: A list of tags associated with the metric.
        :type tags: [str], optional

        :param type: The type of metric. The available types are ``0`` (unspecified), ``1`` (count), ``2`` (rate), and ``3`` (gauge).
        :type type: MetricIntakeType, optional

        :param unit: The unit of point value.
        :type unit: str, optional
        """
        if interval is not unset:
            kwargs["interval"] = interval
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if resources is not unset:
            kwargs["resources"] = resources
        if source_type_name is not unset:
            kwargs["source_type_name"] = source_type_name
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        if unit is not unset:
            kwargs["unit"] = unit
        super().__init__(kwargs)

        self_.metric = metric
        self_.points = points



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.point import Point


class Series(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.point import Point

        return {
            "host": (str,),
            "interval": (int, none_type),
            "metric": (str,),
            "points": ([Point],),
            "tags": ([str],),
            "type": (str,),
        }

    attribute_map = {
        "host": "host",
        "interval": "interval",
        "metric": "metric",
        "points": "points",
        "tags": "tags",
        "type": "type",
    }

    def __init__(
        self_,
        metric: str,
        points: List[Point],
        host: Union[str, UnsetType] = unset,
        interval: Union[int, none_type, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A metric to submit to Datadog.
        See `Datadog metrics <https://docs.datadoghq.com/developers/metrics/#custom-metrics-properties>`_.

        :param host: The name of the host that produced the metric.
        :type host: str, optional

        :param interval: If the type of the metric is rate or count, define the corresponding interval.
        :type interval: int, none_type, optional

        :param metric: The name of the timeseries.
        :type metric: str

        :param points: Points relating to a metric. All points must be tuples with timestamp and a scalar value (cannot be a string). Timestamps should be in POSIX time in seconds, and cannot be more than ten minutes in the future or more than one hour in the past.
        :type points: [Point]

        :param tags: A list of tags associated with the metric.
        :type tags: [str], optional

        :param type: The type of the metric. Valid types are "", ``count`` , ``gauge`` , and ``rate``.
        :type type: str, optional
        """
        if host is not unset:
            kwargs["host"] = host
        if interval is not unset:
            kwargs["interval"] = interval
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)

        self_.metric = metric
        self_.points = points



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_author import NotebookAuthor
    from datadog_api_client.v1.model.notebook_cell_response import NotebookCellResponse
    from datadog_api_client.v1.model.notebook_metadata import NotebookMetadata
    from datadog_api_client.v1.model.notebook_status import NotebookStatus
    from datadog_api_client.v1.model.notebook_global_time import NotebookGlobalTime
    from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
    from datadog_api_client.v1.model.notebook_absolute_time import NotebookAbsoluteTime


class NotebooksResponseDataAttributes(ModelNormal):
    validations = {
        "name": {
            "max_length": 80,
            "min_length": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_author import NotebookAuthor
        from datadog_api_client.v1.model.notebook_cell_response import NotebookCellResponse
        from datadog_api_client.v1.model.notebook_metadata import NotebookMetadata
        from datadog_api_client.v1.model.notebook_status import NotebookStatus
        from datadog_api_client.v1.model.notebook_global_time import NotebookGlobalTime

        return {
            "author": (NotebookAuthor,),
            "cells": ([NotebookCellResponse],),
            "created": (datetime,),
            "metadata": (NotebookMetadata,),
            "modified": (datetime,),
            "name": (str,),
            "status": (NotebookStatus,),
            "time": (NotebookGlobalTime,),
        }

    attribute_map = {
        "author": "author",
        "cells": "cells",
        "created": "created",
        "metadata": "metadata",
        "modified": "modified",
        "name": "name",
        "status": "status",
        "time": "time",
    }
    read_only_vars = {
        "created",
        "modified",
    }

    def __init__(
        self_,
        name: str,
        author: Union[NotebookAuthor, UnsetType] = unset,
        cells: Union[List[NotebookCellResponse], UnsetType] = unset,
        created: Union[datetime, UnsetType] = unset,
        metadata: Union[NotebookMetadata, UnsetType] = unset,
        modified: Union[datetime, UnsetType] = unset,
        status: Union[NotebookStatus, UnsetType] = unset,
        time: Union[NotebookGlobalTime, NotebookRelativeTime, NotebookAbsoluteTime, UnsetType] = unset,
        **kwargs,
    ):
        """
        The attributes of a notebook in get all response.

        :param author: Attributes of user object returned by the API.
        :type author: NotebookAuthor, optional

        :param cells: List of cells to display in the notebook.
        :type cells: [NotebookCellResponse], optional

        :param created: UTC time stamp for when the notebook was created.
        :type created: datetime, optional

        :param metadata: Metadata associated with the notebook.
        :type metadata: NotebookMetadata, optional

        :param modified: UTC time stamp for when the notebook was last modified.
        :type modified: datetime, optional

        :param name: The name of the notebook.
        :type name: str

        :param status: Publication status of the notebook. For now, always "published".
        :type status: NotebookStatus, optional

        :param time: Notebook global timeframe.
        :type time: NotebookGlobalTime, optional
        """
        if author is not unset:
            kwargs["author"] = author
        if cells is not unset:
            kwargs["cells"] = cells
        if created is not unset:
            kwargs["created"] = created
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if modified is not unset:
            kwargs["modified"] = modified
        if status is not unset:
            kwargs["status"] = status
        if time is not unset:
            kwargs["time"] = time
        super().__init__(kwargs)

        self_.name = name



"""
Get Confluent account returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.confluent_cloud_api import ConfluentCloudApi

# there is a valid "confluent_account" in the system
CONFLUENT_ACCOUNT_DATA_ID = environ["CONFLUENT_ACCOUNT_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ConfluentCloudApi(api_client)
    response = api_instance.get_confluent_account(
        account_id=CONFLUENT_ACCOUNT_DATA_ID,
    )

    print(response)



"""
Create a new dashboard with apm resource stats widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.formula_and_function_apm_resource_stat_name import (
    FormulaAndFunctionApmResourceStatName,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_data_source import (
    FormulaAndFunctionApmResourceStatsDataSource,
)
from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_query_definition import (
    FormulaAndFunctionApmResourceStatsQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.table_widget_definition import TableWidgetDefinition
from datadog_api_client.v1.model.table_widget_definition_type import TableWidgetDefinitionType
from datadog_api_client.v1.model.table_widget_request import TableWidgetRequest
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_apm_resource_stats_widget",
    widgets=[
        Widget(
            definition=TableWidgetDefinition(
                title="",
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                type=TableWidgetDefinitionType.QUERY_TABLE,
                requests=[
                    TableWidgetRequest(
                        response_format=FormulaAndFunctionResponseFormat.SCALAR,
                        queries=[
                            FormulaAndFunctionApmResourceStatsQueryDefinition(
                                primary_tag_value="edge-eu1.prod.dog",
                                stat=FormulaAndFunctionApmResourceStatName.HITS,
                                name="query1",
                                service="cassandra",
                                data_source=FormulaAndFunctionApmResourceStatsDataSource.APM_RESOURCE_STATS,
                                env="ci",
                                primary_tag_name="datacenter",
                                operation_name="cassandra.query",
                                group_by=[
                                    "resource_name",
                                ],
                            ),
                        ],
                    ),
                ],
            ),
            layout=WidgetLayout(
                x=0,
                y=0,
                width=4,
                height=4,
            ),
        ),
    ],
    layout_type=DashboardLayoutType.ORDERED,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class LogsMetricResponseGroupBy(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "path": (str,),
            "tag_name": (str,),
        }

    attribute_map = {
        "path": "path",
        "tag_name": "tag_name",
    }

    def __init__(self_, path: Union[str, UnsetType] = unset, tag_name: Union[str, UnsetType] = unset, **kwargs):
        """
        A group by rule.

        :param path: The path to the value the log-based metric will be aggregated over.
        :type path: str, optional

        :param tag_name: Eventual name of the tag that gets created. By default, the path attribute is used as the tag name.
        :type tag_name: str, optional
        """
        if path is not unset:
            kwargs["path"] = path
        if tag_name is not unset:
            kwargs["tag_name"] = tag_name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class UsageTopAvgMetricsPagination(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "limit": (int,),
            "next_record_id": (str, none_type),
            "total_number_of_records": (int,),
        }

    attribute_map = {
        "limit": "limit",
        "next_record_id": "next_record_id",
        "total_number_of_records": "total_number_of_records",
    }

    def __init__(
        self_,
        limit: Union[int, UnsetType] = unset,
        next_record_id: Union[str, none_type, UnsetType] = unset,
        total_number_of_records: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        The metadata for the current pagination.

        :param limit: Maximum amount of records to be returned.
        :type limit: int, optional

        :param next_record_id: The cursor to get the next results (if any). To make the next request, use the same parameters and add ``next_record_id``.
        :type next_record_id: str, none_type, optional

        :param total_number_of_records: Total number of records.
        :type total_number_of_records: int, optional
        """
        if limit is not unset:
            kwargs["limit"] = limit
        if next_record_id is not unset:
            kwargs["next_record_id"] = next_record_id
        if total_number_of_records is not unset:
            kwargs["total_number_of_records"] = total_number_of_records
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsCheckType(ModelSimple):
    """
    Type of assertion to apply in an API test.

    :param value: Must be one of ["equals", "notEquals", "contains", "notContains", "startsWith", "notStartsWith", "greater", "lower", "greaterEquals", "lowerEquals", "matchRegex", "between", "isEmpty", "notIsEmpty"].
    :type value: str
    """

    allowed_values = {
        "equals",
        "notEquals",
        "contains",
        "notContains",
        "startsWith",
        "notStartsWith",
        "greater",
        "lower",
        "greaterEquals",
        "lowerEquals",
        "matchRegex",
        "between",
        "isEmpty",
        "notIsEmpty",
    }
    EQUALS: ClassVar["SyntheticsCheckType"]
    NOT_EQUALS: ClassVar["SyntheticsCheckType"]
    CONTAINS: ClassVar["SyntheticsCheckType"]
    NOT_CONTAINS: ClassVar["SyntheticsCheckType"]
    STARTS_WITH: ClassVar["SyntheticsCheckType"]
    NOT_STARTS_WITH: ClassVar["SyntheticsCheckType"]
    GREATER: ClassVar["SyntheticsCheckType"]
    LOWER: ClassVar["SyntheticsCheckType"]
    GREATER_EQUALS: ClassVar["SyntheticsCheckType"]
    LOWER_EQUALS: ClassVar["SyntheticsCheckType"]
    MATCH_REGEX: ClassVar["SyntheticsCheckType"]
    BETWEEN: ClassVar["SyntheticsCheckType"]
    IS_EMPTY: ClassVar["SyntheticsCheckType"]
    NOT_IS_EMPTY: ClassVar["SyntheticsCheckType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsCheckType.EQUALS = SyntheticsCheckType("equals")
SyntheticsCheckType.NOT_EQUALS = SyntheticsCheckType("notEquals")
SyntheticsCheckType.CONTAINS = SyntheticsCheckType("contains")
SyntheticsCheckType.NOT_CONTAINS = SyntheticsCheckType("notContains")
SyntheticsCheckType.STARTS_WITH = SyntheticsCheckType("startsWith")
SyntheticsCheckType.NOT_STARTS_WITH = SyntheticsCheckType("notStartsWith")
SyntheticsCheckType.GREATER = SyntheticsCheckType("greater")
SyntheticsCheckType.LOWER = SyntheticsCheckType("lower")
SyntheticsCheckType.GREATER_EQUALS = SyntheticsCheckType("greaterEquals")
SyntheticsCheckType.LOWER_EQUALS = SyntheticsCheckType("lowerEquals")
SyntheticsCheckType.MATCH_REGEX = SyntheticsCheckType("matchRegex")
SyntheticsCheckType.BETWEEN = SyntheticsCheckType("between")
SyntheticsCheckType.IS_EMPTY = SyntheticsCheckType("isEmpty")
SyntheticsCheckType.NOT_IS_EMPTY = SyntheticsCheckType("notIsEmpty")



"""
Update archive order returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi
from datadog_api_client.v2.model.logs_archive_order import LogsArchiveOrder
from datadog_api_client.v2.model.logs_archive_order_attributes import LogsArchiveOrderAttributes
from datadog_api_client.v2.model.logs_archive_order_definition import LogsArchiveOrderDefinition
from datadog_api_client.v2.model.logs_archive_order_definition_type import LogsArchiveOrderDefinitionType

body = LogsArchiveOrder(
    data=LogsArchiveOrderDefinition(
        attributes=LogsArchiveOrderAttributes(
            archive_ids=[
                "a2zcMylnM4OCHpYusxIi1g",
                "a2zcMylnM4OCHpYusxIi2g",
                "a2zcMylnM4OCHpYusxIi3g",
            ],
        ),
        type=LogsArchiveOrderDefinitionType.ARCHIVE_ORDER,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsArchivesApi(api_client)
    response = api_instance.update_logs_archive_order(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MetricsListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "_from": (str,),
            "metrics": ([str],),
        }

    attribute_map = {
        "_from": "from",
        "metrics": "metrics",
    }

    def __init__(self_, _from: Union[str, UnsetType] = unset, metrics: Union[List[str], UnsetType] = unset, **kwargs):
        """
        Object listing all metric names stored by Datadog since a given time.

        :param _from: Time when the metrics were active, seconds since the Unix epoch.
        :type _from: str, optional

        :param metrics: List of metric names.
        :type metrics: [str], optional
        """
        if _from is not unset:
            kwargs["_from"] = _from
        if metrics is not unset:
            kwargs["metrics"] = metrics
        super().__init__(kwargs)



"""
Create a dashboard list returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboard_lists_api import DashboardListsApi
from datadog_api_client.v1.model.dashboard_list import DashboardList

body = DashboardList(
    name="Example-Create_a_dashboard_list_returns_OK_response",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardListsApi(api_client)
    response = api_instance.create_dashboard_list(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class SearchSLOResponseLinks(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "first": (str,),
            "last": (str, none_type),
            "next": (str,),
            "prev": (str, none_type),
            "self": (str,),
        }

    attribute_map = {
        "first": "first",
        "last": "last",
        "next": "next",
        "prev": "prev",
        "self": "self",
    }

    def __init__(
        self_,
        first: Union[str, UnsetType] = unset,
        last: Union[str, none_type, UnsetType] = unset,
        next: Union[str, UnsetType] = unset,
        prev: Union[str, none_type, UnsetType] = unset,
        self: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Pagination links.

        :param first: Link to last page.
        :type first: str, optional

        :param last: Link to first page.
        :type last: str, none_type, optional

        :param next: Link to the next page.
        :type next: str, optional

        :param prev: Link to previous page.
        :type prev: str, none_type, optional

        :param self: Link to current page.
        :type self: str, optional
        """
        if first is not unset:
            kwargs["first"] = first
        if last is not unset:
            kwargs["last"] = last
        if next is not unset:
            kwargs["next"] = next
        if prev is not unset:
            kwargs["prev"] = prev
        if self is not unset:
            kwargs["self"] = self
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.

import json
import atexit
import mimetypes
import warnings
import multiprocessing
from multiprocessing.pool import ThreadPool
import io
import os
import re
from typing import Any, Dict, Optional, List, Tuple, Union
from urllib.parse import quote
from urllib3.fields import RequestField  # type: ignore


from datadog_api_client import rest
from datadog_api_client.exceptions import ApiTypeError, ApiValueError
from datadog_api_client.model_utils import (
    ModelNormal,
    ModelSimple,
    ModelComposed,
    check_allowed_values,
    check_validations,
    date,
    datetime,
    deserialize_file,
    file_type,
    model_to_dict,
    validate_and_convert_types,
)


class ApiClient(object):
    """Generic API client for OpenAPI client library builds.

    OpenAPI generic API client. This client handles the client-
    server communication, and is invariant across implementations. Specifics of
    the methods and models for each application are generated from the OpenAPI
    templates.

    :param configuration: Configuration object for this client
    :param header_name: A header to pass when making calls to the API.
    :param header_value: A header value to pass when making calls to
        the API.
    """

    def __init__(self, configuration):
        self.configuration = configuration

        self.rest_client = self._build_rest_client()
        self.default_headers = {}
        if self.configuration.compress:
            self.default_headers["Accept-Encoding"] = "gzip"
        # Set default User-Agent.
        self.user_agent = user_agent()

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.close()

    def close(self):
        self.rest_client.pool_manager.clear()

    def _build_rest_client(self):
        return rest.RESTClientObject(self.configuration)

    @property
    def user_agent(self):
        """User agent for this API client"""
        return self.default_headers["User-Agent"]

    @user_agent.setter
    def user_agent(self, value):
        self.default_headers["User-Agent"] = value

    def set_default_header(self, header_name, header_value):
        self.default_headers[header_name] = header_value

    def _call_api(
        self,
        method: str,
        url: str,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Optional[Any] = None,
        post_params: Optional[List[Tuple[str, Any]]] = None,
        response_type: Optional[Tuple[Any]] = None,
        return_http_data_only: Optional[bool] = None,
        preload_content: bool = True,
        request_timeout: Optional[Union[int, float, Tuple]] = None,
        check_type: Optional[bool] = None,
    ):
        # perform request and return response
        response = self.rest_client.request(
            method,
            url,
            query_params=query_params,
            headers=header_params,
            post_params=post_params,
            body=body,
            preload_content=preload_content,
            request_timeout=request_timeout,
        )

        if not preload_content:
            return response

        # deserialize response data
        if response_type:
            if response_type == (file_type,):
                content_disposition = response.getheader("Content-Disposition")
                return_data = deserialize_file(
                    response.data, self.configuration.temp_folder_path, content_disposition=content_disposition
                )
            else:
                encoding = "utf-8"
                content_type = response.getheader("content-type")
                if content_type is not None:
                    match = re.search(r"charset=([a-zA-Z\-\d]+)[\s\;]?", content_type)
                    if match:
                        encoding = match.group(1)
                response_data = response.data.decode(encoding)

                return_data = self.deserialize(response_data, response_type, check_type)
        else:
            return_data = None

        if return_http_data_only:
            return return_data
        return (return_data, response.status, response.getheaders())

    def parameters_to_multipart(self, params, collection_types):
        """Get parameters as list of tuples, formatting as json if value is collection_types.

        :param params: Parameters as list of two-tuples.
        :param collection_types: Parameter collection types.

        :return: Parameters as list of tuple or urllib3.fields.RequestField
        """
        new_params = []
        if collection_types is None:
            collection_types = dict
        for k, v in params.items() if isinstance(params, dict) else params:
            if isinstance(v, collection_types):  # v is instance of collection_type, formatting as application/json
                v = json.dumps(v, ensure_ascii=False).encode("utf-8")
                field = RequestField(k, v)
                field.make_multipart(content_type="application/json; charset=utf-8")
                new_params.append(field)
            else:
                new_params.append((k, v))
        return new_params

    @classmethod
    def sanitize_for_serialization(cls, obj):
        """Prepares data for transmission before it is sent with the rest client.
        If obj is None, return None.
        If obj is str, int, long, float, bool, return directly.
        If obj is datetime.datetime, datetime.date convert to string in iso8601 format.
        If obj is list, sanitize each element in the list.
        If obj is dict, return the dict.
        If obj is OpenAPI model, return the properties dict.
        If obj is io.IOBase, return the bytes.

        :param obj: The data to serialize.
        :return: The serialized form of data.
        """
        if isinstance(obj, (ModelNormal, ModelComposed)):
            return {key: cls.sanitize_for_serialization(val) for key, val in model_to_dict(obj).items()}
        elif isinstance(obj, io.IOBase):
            return cls.get_file_data_and_close_file(obj)
        elif isinstance(obj, (str, int, float, bool)) or obj is None:
            return obj
        elif isinstance(obj, (datetime, date)):
            if obj.tzinfo is not None:
                return obj.isoformat()
            return obj.strftime("%Y-%m-%dT%H:%M:%S") + obj.strftime(".%f")[:4] + "Z"
        elif isinstance(obj, ModelSimple):
            return cls.sanitize_for_serialization(obj.value)
        elif isinstance(obj, (list, tuple)):
            return [cls.sanitize_for_serialization(item) for item in obj]
        if isinstance(obj, dict):
            return {key: cls.sanitize_for_serialization(val) for key, val in obj.items()}
        raise ApiValueError("Unable to prepare type {} for serialization".format(obj.__class__.__name__))

    def deserialize(self, response_data, response_type, check_type):
        """Deserializes response into an object.

        :param response_data: Response data to be deserialized.
        :param response_type: For the response, a tuple containing:
            valid classes
            a list containing valid classes (for list schemas)
            a dict containing a tuple of valid classes as the value
            Example values:
            (str,)
            (Pet,)
            (float, none_type)
            ([int, none_type],)
            ({str: (bool, str, int, float, date, datetime, str, none_type)},)
        :param check_type: boolean, whether to check the types of the data
            received from the server
        :type check_type: bool

        :return: deserialized object.
        """
        # fetch data from response object
        try:
            received_data = json.loads(response_data)
        except ValueError:
            received_data = response_data

        # store our data under the key of 'received_data' so users have some
        # context if they are deserializing a string and the data type is wrong
        deserialized_data = validate_and_convert_types(
            received_data, response_type, ["received_data"], True, check_type, configuration=self.configuration
        )
        return deserialized_data

    def call_api(
        self,
        resource_path: str,
        method: str,
        path_params: Optional[Dict[str, Any]] = None,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Optional[Any] = None,
        post_params: Optional[List[Tuple[str, Any]]] = None,
        files: Optional[Dict[str, List[io.FileIO]]] = None,
        response_type: Optional[Tuple[Any]] = None,
        return_http_data_only: Optional[bool] = None,
        collection_formats: Optional[Dict[str, str]] = None,
        preload_content: bool = True,
        request_timeout: Optional[Union[int, float, Tuple]] = None,
        host: Optional[str] = None,
        check_type: Optional[bool] = None,
    ):
        """Makes the HTTP request (synchronous) and returns deserialized data.

        :param resource_path: Path to method endpoint.
        :param method: Method to call.
        :param path_params: Path parameters in the url.
        :param query_params: Query parameters in the url.
        :param header_params: Header parameters to be
            placed in the request header.
        :param body: Request body.
        :param post_params dict: Request post form parameters,
            for `application/x-www-form-urlencoded`, `multipart/form-data`.
        :param response_type: For the response, a tuple containing:
            valid classes
            a list containing valid classes (for list schemas)
            a dict containing a tuple of valid classes as the value
            Example values:
            (str,)
            (Pet,)
            (float, none_type)
            ([int, none_type],)
            ({str: (bool, str, int, float, date, datetime, str, none_type)},)
        :param files: key -> field name, value -> a list of open file
            objects for `multipart/form-data`.
        :type files: dict
        :param return_http_data_only: response data without head status code
                                       and headers
        :type return_http_data_only: bool, optional
        :param collection_formats: dict of collection formats for path, query,
            header, and post parameters.
        :type collection_formats: dict, optional
        :param preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type preload_content: bool, optional
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param check_type: boolean describing if the data back from the server
            should have its type checked.
        :type check_type: bool, optional
        :return: the HTTP response.
        """
        # header parameters
        header_params = header_params or {}
        header_params.update(self.default_headers)
        if header_params:
            header_params = self.sanitize_for_serialization(header_params)
            header_params = dict(self.parameters_to_tuples(header_params, collection_formats))

        # path parameters
        if path_params:
            path_params = self.sanitize_for_serialization(path_params)
            for k, v in self.parameters_to_tuples(path_params, collection_formats):
                # specified safe chars, encode everything
                resource_path = resource_path.replace(
                    f"{{{k}}}", quote(str(v), safe=self.configuration.safe_chars_for_path_param)
                )

        # query parameters
        if query_params:
            query_params = self.sanitize_for_serialization(query_params)
            query_params = self.parameters_to_tuples(query_params, collection_formats)

        # post parameters
        if post_params or files:
            post_params = post_params or []
            post_params = self.sanitize_for_serialization(post_params)
            post_params = self.parameters_to_tuples(post_params, collection_formats)
            post_params.extend(self.files_parameters(files))
            if header_params["Content-Type"].startswith("multipart"):
                post_params = self.parameters_to_multipart(post_params, (dict))

        # body
        if body:
            body = self.sanitize_for_serialization(body)

        # request url
        if host is None:
            url = self.configuration.host + resource_path
        else:
            # use server/host defined in path or operation instead
            url = host + resource_path

        return self._call_api(
            method,
            url,
            query_params,
            header_params,
            body,
            post_params,
            response_type,
            return_http_data_only,
            preload_content,
            request_timeout,
            check_type,
        )

    def parameters_to_tuples(self, params, collection_formats) -> List[Tuple[str, Any]]:
        """Get parameters as list of tuples, formatting collections.

        :param params: Parameters as dict or list of two-tuples
        :param dict collection_formats: Parameter collection formats
        :return: Parameters as list of tuples, collections formatted
        """
        new_params: List[Tuple[str, str]] = []
        if collection_formats is None:
            collection_formats = {}
        for k, v in params.items() if isinstance(params, dict) else params:
            if k in collection_formats:
                collection_format = collection_formats[k]
                if collection_format == "multi":
                    new_params.extend((k, value) for value in v)
                else:
                    if collection_format == "ssv":
                        delimiter = " "
                    elif collection_format == "tsv":
                        delimiter = "\t"
                    elif collection_format == "pipes":
                        delimiter = "|"
                    else:  # csv is the default
                        delimiter = ","
                    new_params.append((k, delimiter.join(str(value) for value in v)))
            else:
                if isinstance(v, bool):
                    v = json.dumps(v)
                new_params.append((k, v))
        return new_params

    @staticmethod
    def get_file_data_and_close_file(file_instance: io.IOBase) -> bytes:
        file_data = file_instance.read()
        file_instance.close()
        return file_data

    def files_parameters(self, files: Optional[Dict[str, List[io.FileIO]]] = None):
        """Builds form parameters.

        :param files: None or a dict with key=param_name and
            value is a list of open file objects
        :return: List of tuples of form parameters with file data
        """
        if files is None:
            return []

        params = []
        for param_name, file_instances in files.items():
            if file_instances is None:
                # if the file field is nullable, skip None values
                continue
            for file_instance in file_instances:
                if file_instance is None:
                    # if the file field is nullable, skip None values
                    continue
                if file_instance.closed is True:
                    raise ApiValueError(
                        "Cannot read a closed file. The passed in file_type " "for %s must be open." % param_name
                    )
                filename = os.path.basename(str(file_instance.name))
                filedata = self.get_file_data_and_close_file(file_instance)
                mimetype = mimetypes.guess_type(filename)[0] or "application/octet-stream"
                params.append(tuple([param_name, tuple([filename, filedata, mimetype])]))

        return params

    def select_header_accept(self, accepts):
        """Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        return ", ".join(accepts)

    def select_header_content_type(self, content_types):
        """Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return "application/json"

        content_types = [x.lower() for x in content_types]

        if "application/json" in content_types or "*/*" in content_types:
            return "application/json"
        return content_types[0]


class ThreadedApiClient(ApiClient):

    _pool = None

    def __init__(self, configuration, pool_threads=1):
        self.pool_threads = pool_threads
        self.connection_pool_maxsize = multiprocessing.cpu_count() * 5
        super().__init__(configuration)

    def _build_rest_client(self):
        return rest.RESTClientObject(self.configuration, maxsize=self.connection_pool_maxsize)

    def close(self):
        self.rest_client.pool_manager.clear()
        if self._pool:
            self._pool.close()
            self._pool.join()
            self._pool = None
            if hasattr(atexit, "unregister"):
                atexit.unregister(self.close)

    @property
    def pool(self):
        """Create thread pool on first request
        avoids instantiating unused threadpool for blocking clients.
        """
        if self._pool is None:
            atexit.register(self.close)
            self._pool = ThreadPool(self.pool_threads)
        return self._pool

    def _call_api(
        self,
        method: str,
        url: str,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Optional[Any] = None,
        post_params: Optional[List[Tuple[str, Any]]] = None,
        response_type: Optional[Tuple[Any]] = None,
        return_http_data_only: Optional[bool] = None,
        preload_content: bool = True,
        request_timeout: Optional[Union[int, float, Tuple]] = None,
        check_type: Optional[bool] = None,
    ):
        return self.pool.apply_async(
            super()._call_api,
            (
                method,
                url,
                query_params,
                header_params,
                body,
                post_params,
                response_type,
                return_http_data_only,
                preload_content,
                request_timeout,
                check_type,
            ),
        )


class AsyncApiClient(ApiClient):
    def _build_rest_client(self):
        return rest.AsyncRESTClientObject(self.configuration)

    async def __aenter__(self):
        return self

    async def __aexit__(self, _exc_type, exc, _tb):
        if exc:
            raise exc
        await self.rest_client._client.shutdown()

    async def _call_api(
        self,
        method: str,
        url: str,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Optional[Any] = None,
        post_params: Optional[List[Tuple[str, Any]]] = None,
        response_type: Optional[Tuple[Any]] = None,
        return_http_data_only: Optional[bool] = None,
        preload_content: bool = True,
        request_timeout: Optional[Union[int, float, Tuple]] = None,
        check_type: Optional[bool] = None,
    ):

        # perform request and return response
        response = await self.rest_client.request(
            method,
            url,
            query_params=query_params,
            headers=header_params,
            post_params=post_params,
            body=body,
            preload_content=preload_content,
            request_timeout=request_timeout,
        )

        if not preload_content:
            return response

        # deserialize response data
        if response_type:
            if response_type == (file_type,):
                content_disposition = response.headers.get("Content-Disposition")
                response_data = await response.content()
                return_data = deserialize_file(
                    response_data, self.configuration.temp_folder_path, content_disposition=content_disposition
                )
            else:
                response_data = await response.text()

                return_data = self.deserialize(response_data, response_type, check_type)
        else:
            return_data = None

        if return_http_data_only:
            return return_data
        return (return_data, response.status_code, response.headers)


class Endpoint(object):
    def __init__(self, settings=None, params_map=None, headers_map=None, api_client=None):
        """Creates an endpoint.

        :param settings: See below key value pairs:
            'response_type' (tuple/None): response type
            'auth' (list): a list of auth type keys
            'endpoint_path' (str): the endpoint path
            'operation_id' (str): endpoint string identifier
            'http_method' (str): POST/PUT/PATCH/GET etc
            'servers' (list): list of str servers that this endpoint is at
            'version' (str): the API version
        :type settings: dict
        :param params_map: See below key value pairs:
            'required' (bool): whether the parameter is required
            'nullable' (bool): whether the parameter is nullable
            'validations' (dict): the validations dictionaries
            'allowed_values' (dict): the allowed values (enum) dictionaries
            'openapi_types' (dict): param_name to openapi type
            'attribute' (str): camelCase name
            'location' (str): 'body', 'file', 'form', 'header', 'path', 'query'
            'collection_format' (str): `csv` etc.
        :type params_map: dict
        :param headers_map: See below key value pairs:
            'accept' (list): list of Accept header strings
            'content_type' (list): list of Content-Type header strings
        :type headers_map: dict
        :param api_client API client instance.
        :type api_client: ApiClient
        """
        self.settings = settings
        self.params_map = params_map
        self.headers_map = headers_map
        self.api_client = api_client

    def _validate_inputs(self, kwargs):
        for param in kwargs:
            param_map = self.params_map[param]
            allowed_values = param_map.get("allowed_values")
            if allowed_values:
                check_allowed_values(list(allowed_values.values()), param, kwargs[param])

            validations = param_map.get("validation")
            if validations:
                check_validations(validations, param, kwargs[param], configuration=self.api_client.configuration)

        if not self.api_client.configuration.check_input_type:
            return

        for key, value in kwargs.items():
            fixed_val = validate_and_convert_types(
                value,
                self.params_map[key]["openapi_types"],
                [key],
                self.api_client.configuration.spec_property_naming,
                self.api_client.configuration.check_input_type,
                configuration=self.api_client.configuration,
            )
            kwargs[key] = fixed_val

    def _gather_params(self, kwargs):
        params = {"body": None, "collection_format": {}, "file": {}, "form": [], "header": {}, "path": {}, "query": []}

        for param_name, param_value in kwargs.items():
            param_map = self.params_map[param_name]
            param_location = param_map.get("location")
            if param_location is None:
                continue
            if param_location:
                if param_location == "body":
                    params["body"] = param_value
                    continue
                base_name = param_map["attribute"]
                openapi_types = param_map["openapi_types"]
                if param_location == "form" and openapi_types == (file_type,):
                    params["file"][param_name] = [param_value]
                elif param_location == "form" and openapi_types == ([file_type],):
                    # param_value is already a list
                    params["file"][param_name] = param_value
                elif param_location in {"form", "query"}:
                    param_value_full = (base_name, param_value)
                    params[param_location].append(param_value_full)
                if param_location not in {"form", "query"}:
                    params[param_location][base_name] = param_value
                collection_format = param_map.get("collection_format")
                if collection_format:
                    params["collection_format"][base_name] = collection_format

        return params

    def call_with_http_info(self, **kwargs):

        is_unstable = self.api_client.configuration.unstable_operations.get(
            "{}.{}".format(self.settings["version"], self.settings["operation_id"])
        )
        if is_unstable:
            warnings.warn("Using unstable operation '{0}'".format(self.settings["operation_id"]))
        elif is_unstable is False:
            raise ApiValueError("Unstable operation '{0}' is disabled".format(self.settings["operation_id"]))

        try:
            index = self.api_client.configuration.server_operation_index.get(
                self.settings["operation_id"], self.api_client.configuration.server_index
            )
            server_variables = self.api_client.configuration.server_operation_variables.get(
                self.settings["operation_id"], self.api_client.configuration.server_variables
            )
            host = self.api_client.configuration.get_host_from_settings(
                index, variables=server_variables, servers=self.settings["servers"]
            )
        except IndexError:
            if self.settings["servers"]:
                raise ApiValueError("Invalid host index. Must be 0 <= index < %s" % len(self.settings["servers"]))
            host = None

        for key, value in kwargs.items():
            if key not in self.params_map:
                raise ApiTypeError(
                    "Got an unexpected parameter '%s'" " to method `%s`" % (key, self.settings["operation_id"])
                )
            # only throw this nullable ApiValueError if check_input_type
            # is False, if check_input_type==True we catch this case
            # in self._validate_inputs
            if (
                not self.params_map[key].get("nullable")
                and value is None
                and not self.api_client.configuration.check_input_type
            ):
                raise ApiValueError(
                    "Value may not be None for non-nullable parameter `%s`"
                    " when calling `%s`" % (key, self.settings["operation_id"])
                )

        for key, param_map in self.params_map.items():
            if param_map.get("required") and key not in kwargs:
                raise ApiValueError(
                    "Missing the required parameter `%s` when calling " "`%s`" % (key, self.settings["operation_id"])
                )

        self._validate_inputs(kwargs)

        params = self._gather_params(kwargs)

        accept_headers_list = self.headers_map["accept"]
        if accept_headers_list:
            params["header"]["Accept"] = self.api_client.select_header_accept(accept_headers_list)

        content_type_headers_list = self.headers_map["content_type"]
        if content_type_headers_list:
            header_list = self.api_client.select_header_content_type(content_type_headers_list)
            params["header"]["Content-Type"] = header_list

        self.update_params_for_auth(params["header"], params["query"])

        return self.api_client.call_api(
            self.settings["endpoint_path"],
            self.settings["http_method"],
            params["path"],
            params["query"],
            params["header"],
            body=params["body"],
            post_params=params["form"],
            files=params["file"],
            response_type=self.settings["response_type"],
            check_type=self.api_client.configuration.check_return_type,
            return_http_data_only=self.api_client.configuration.return_http_data_only,
            preload_content=self.api_client.configuration.preload_content,
            request_timeout=self.api_client.configuration.request_timeout,
            host=host,
            collection_formats=params["collection_format"],
        )

    def update_params_for_auth(self, headers, queries):
        """Updates header and query params based on authentication setting.

        :param headers: Header parameters dict to be updated.
        :param queries: Query parameters tuple list to be updated.
        """
        if not self.settings["auth"]:
            return

        for auth in self.settings["auth"]:
            auth_setting = self.api_client.configuration.auth_settings().get(auth)
            if auth_setting:
                if auth_setting["in"] == "header":
                    if auth_setting["type"] != "http-signature":
                        if auth_setting["value"] is None:
                            raise ApiValueError("Invalid authentication token for {}".format(auth_setting["key"]))
                        headers[auth_setting["key"]] = auth_setting["value"]
                elif auth_setting["in"] == "query":
                    queries.append((auth_setting["key"], auth_setting["value"]))
                else:
                    raise ApiValueError("Authentication token must be in `query` or `header`")


def user_agent():
    """Generate default User-Agent header."""
    import platform
    from datadog_api_client.version import __version__

    return "datadog-api-client-python/{version} (python {py}; os {os}; arch {arch})".format(
        version=__version__,
        py=platform.python_version(),
        os=platform.system(),
        arch=platform.machine(),
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleEvaluationWindow(ModelSimple):
    """
    A time window is specified to match when at least one of the cases matches true. This is a sliding window
        and evaluates in real time.

    :param value: Must be one of [0, 60, 300, 600, 900, 1800, 3600, 7200].
    :type value: int
    """

    allowed_values = {
        0,
        60,
        300,
        600,
        900,
        1800,
        3600,
        7200,
    }
    ZERO_MINUTES: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    ONE_MINUTE: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    FIVE_MINUTES: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    TEN_MINUTES: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    FIFTEEN_MINUTES: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    THIRTY_MINUTES: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    ONE_HOUR: ClassVar["SecurityMonitoringRuleEvaluationWindow"]
    TWO_HOURS: ClassVar["SecurityMonitoringRuleEvaluationWindow"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (int,),
        }


SecurityMonitoringRuleEvaluationWindow.ZERO_MINUTES = SecurityMonitoringRuleEvaluationWindow(0)
SecurityMonitoringRuleEvaluationWindow.ONE_MINUTE = SecurityMonitoringRuleEvaluationWindow(60)
SecurityMonitoringRuleEvaluationWindow.FIVE_MINUTES = SecurityMonitoringRuleEvaluationWindow(300)
SecurityMonitoringRuleEvaluationWindow.TEN_MINUTES = SecurityMonitoringRuleEvaluationWindow(600)
SecurityMonitoringRuleEvaluationWindow.FIFTEEN_MINUTES = SecurityMonitoringRuleEvaluationWindow(900)
SecurityMonitoringRuleEvaluationWindow.THIRTY_MINUTES = SecurityMonitoringRuleEvaluationWindow(1800)
SecurityMonitoringRuleEvaluationWindow.ONE_HOUR = SecurityMonitoringRuleEvaluationWindow(3600)
SecurityMonitoringRuleEvaluationWindow.TWO_HOURS = SecurityMonitoringRuleEvaluationWindow(7200)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.synthetics_batch_details import SyntheticsBatchDetails
from datadog_api_client.v1.model.synthetics_locations import SyntheticsLocations
from datadog_api_client.v1.model.synthetics_private_location_creation_response import (
    SyntheticsPrivateLocationCreationResponse,
)
from datadog_api_client.v1.model.synthetics_private_location import SyntheticsPrivateLocation
from datadog_api_client.v1.model.synthetics_list_tests_response import SyntheticsListTestsResponse
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_browser_test import SyntheticsBrowserTest
from datadog_api_client.v1.model.synthetics_get_browser_test_latest_results_response import (
    SyntheticsGetBrowserTestLatestResultsResponse,
)
from datadog_api_client.v1.model.synthetics_browser_test_result_full import SyntheticsBrowserTestResultFull
from datadog_api_client.v1.model.synthetics_delete_tests_response import SyntheticsDeleteTestsResponse
from datadog_api_client.v1.model.synthetics_delete_tests_payload import SyntheticsDeleteTestsPayload
from datadog_api_client.v1.model.synthetics_trigger_ci_tests_response import SyntheticsTriggerCITestsResponse
from datadog_api_client.v1.model.synthetics_trigger_body import SyntheticsTriggerBody
from datadog_api_client.v1.model.synthetics_ci_test_body import SyntheticsCITestBody
from datadog_api_client.v1.model.synthetics_test_details import SyntheticsTestDetails
from datadog_api_client.v1.model.synthetics_get_api_test_latest_results_response import (
    SyntheticsGetAPITestLatestResultsResponse,
)
from datadog_api_client.v1.model.synthetics_api_test_result_full import SyntheticsAPITestResultFull
from datadog_api_client.v1.model.synthetics_update_test_pause_status_payload import (
    SyntheticsUpdateTestPauseStatusPayload,
)
from datadog_api_client.v1.model.synthetics_list_global_variables_response import SyntheticsListGlobalVariablesResponse
from datadog_api_client.v1.model.synthetics_global_variable import SyntheticsGlobalVariable


class SyntheticsApi:
    """
    Datadog Synthetics uses simulated user requests and browser rendering to help you ensure uptime,
    identify regional issues, and track your application performance. Datadog Synthetics tests come in
    two different flavors, `API tests <https://docs.datadoghq.com/synthetics/api_tests/?tab=httptest>`_
    and `browser tests <https://docs.datadoghq.com/synthetics/browser_tests>`_. You can use Datadog’s API to
    manage both test types programmatically.

    For more information about Synthetics, see the `Synthetics overview <https://docs.datadoghq.com/synthetics/>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_global_variable_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsGlobalVariable,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/variables",
                "operation_id": "create_global_variable",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsGlobalVariable,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_private_location_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsPrivateLocationCreationResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/private-locations",
                "operation_id": "create_private_location",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsPrivateLocation,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_synthetics_api_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsAPITest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/api",
                "operation_id": "create_synthetics_api_test",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsAPITest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_synthetics_browser_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsBrowserTest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/browser",
                "operation_id": "create_synthetics_browser_test",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsBrowserTest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_global_variable_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/variables/{variable_id}",
                "operation_id": "delete_global_variable",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "variable_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "variable_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._delete_private_location_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/private-locations/{location_id}",
                "operation_id": "delete_private_location",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "location_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "location_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._delete_tests_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsDeleteTestsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/delete",
                "operation_id": "delete_tests",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsDeleteTestsPayload,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._edit_global_variable_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsGlobalVariable,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/variables/{variable_id}",
                "operation_id": "edit_global_variable",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "variable_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "variable_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsGlobalVariable,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._get_api_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsAPITest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/api/{public_id}",
                "operation_id": "get_api_test",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_api_test_latest_results_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsGetAPITestLatestResultsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/{public_id}/results",
                "operation_id": "get_api_test_latest_results",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "from_ts": {
                    "openapi_types": (int,),
                    "attribute": "from_ts",
                    "location": "query",
                },
                "to_ts": {
                    "openapi_types": (int,),
                    "attribute": "to_ts",
                    "location": "query",
                },
                "probe_dc": {
                    "openapi_types": ([str],),
                    "attribute": "probe_dc",
                    "location": "query",
                    "collection_format": "multi",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_api_test_result_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsAPITestResultFull,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/{public_id}/results/{result_id}",
                "operation_id": "get_api_test_result",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "result_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "result_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_browser_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsBrowserTest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/browser/{public_id}",
                "operation_id": "get_browser_test",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_browser_test_latest_results_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsGetBrowserTestLatestResultsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/browser/{public_id}/results",
                "operation_id": "get_browser_test_latest_results",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "from_ts": {
                    "openapi_types": (int,),
                    "attribute": "from_ts",
                    "location": "query",
                },
                "to_ts": {
                    "openapi_types": (int,),
                    "attribute": "to_ts",
                    "location": "query",
                },
                "probe_dc": {
                    "openapi_types": ([str],),
                    "attribute": "probe_dc",
                    "location": "query",
                    "collection_format": "multi",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_browser_test_result_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsBrowserTestResultFull,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/browser/{public_id}/results/{result_id}",
                "operation_id": "get_browser_test_result",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "result_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "result_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_global_variable_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsGlobalVariable,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/variables/{variable_id}",
                "operation_id": "get_global_variable",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "variable_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "variable_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_private_location_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsPrivateLocation,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/private-locations/{location_id}",
                "operation_id": "get_private_location",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "location_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "location_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_synthetics_ci_batch_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsBatchDetails,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/ci/batch/{batch_id}",
                "operation_id": "get_synthetics_ci_batch",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "batch_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "batch_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsTestDetails,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/{public_id}",
                "operation_id": "get_test",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_global_variables_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsListGlobalVariablesResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/variables",
                "operation_id": "list_global_variables",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_locations_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsLocations,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/locations",
                "operation_id": "list_locations",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_tests_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsListTestsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests",
                "operation_id": "list_tests",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "page_size": {
                    "openapi_types": (str,),
                    "attribute": "page_size",
                    "location": "query",
                },
                "page_number": {
                    "openapi_types": (str,),
                    "attribute": "page_number",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._trigger_ci_tests_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsTriggerCITestsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/trigger/ci",
                "operation_id": "trigger_ci_tests",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsCITestBody,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._trigger_tests_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsTriggerCITestsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/trigger",
                "operation_id": "trigger_tests",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsTriggerBody,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_api_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsAPITest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/api/{public_id}",
                "operation_id": "update_api_test",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsAPITest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_browser_test_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsBrowserTest,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/browser/{public_id}",
                "operation_id": "update_browser_test",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsBrowserTest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_private_location_endpoint = _Endpoint(
            settings={
                "response_type": (SyntheticsPrivateLocation,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/private-locations/{location_id}",
                "operation_id": "update_private_location",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "location_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "location_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsPrivateLocation,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_test_pause_status_endpoint = _Endpoint(
            settings={
                "response_type": (bool,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/synthetics/tests/{public_id}/status",
                "operation_id": "update_test_pause_status",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "public_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "public_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SyntheticsUpdateTestPauseStatusPayload,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_global_variable(
        self,
        body: SyntheticsGlobalVariable,
    ) -> SyntheticsGlobalVariable:
        """Create a global variable.

        Create a Synthetics global variable.

        :param body: Details of the global variable to create.
        :type body: SyntheticsGlobalVariable
        :rtype: SyntheticsGlobalVariable
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_global_variable_endpoint.call_with_http_info(**kwargs)

    def create_private_location(
        self,
        body: SyntheticsPrivateLocation,
    ) -> SyntheticsPrivateLocationCreationResponse:
        """Create a private location.

        Create a new Synthetics private location.

        :param body: Details of the private location to create.
        :type body: SyntheticsPrivateLocation
        :rtype: SyntheticsPrivateLocationCreationResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_private_location_endpoint.call_with_http_info(**kwargs)

    def create_synthetics_api_test(
        self,
        body: SyntheticsAPITest,
    ) -> SyntheticsAPITest:
        """Create an API test.

        Create a Synthetic API test.

        :param body: Details of the test to create.
        :type body: SyntheticsAPITest
        :rtype: SyntheticsAPITest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_synthetics_api_test_endpoint.call_with_http_info(**kwargs)

    def create_synthetics_browser_test(
        self,
        body: SyntheticsBrowserTest,
    ) -> SyntheticsBrowserTest:
        """Create a browser test.

        Create a Synthetic browser test.

        :param body: Details of the test to create.
        :type body: SyntheticsBrowserTest
        :rtype: SyntheticsBrowserTest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_synthetics_browser_test_endpoint.call_with_http_info(**kwargs)

    def delete_global_variable(
        self,
        variable_id: str,
    ) -> None:
        """Delete a global variable.

        Delete a Synthetics global variable.

        :param variable_id: The ID of the global variable.
        :type variable_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["variable_id"] = variable_id

        return self._delete_global_variable_endpoint.call_with_http_info(**kwargs)

    def delete_private_location(
        self,
        location_id: str,
    ) -> None:
        """Delete a private location.

        Delete a Synthetics private location.

        :param location_id: The ID of the private location.
        :type location_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["location_id"] = location_id

        return self._delete_private_location_endpoint.call_with_http_info(**kwargs)

    def delete_tests(
        self,
        body: SyntheticsDeleteTestsPayload,
    ) -> SyntheticsDeleteTestsResponse:
        """Delete tests.

        Delete multiple Synthetic tests by ID.

        :param body: Public ID list of the Synthetic tests to be deleted.
        :type body: SyntheticsDeleteTestsPayload
        :rtype: SyntheticsDeleteTestsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._delete_tests_endpoint.call_with_http_info(**kwargs)

    def edit_global_variable(
        self,
        variable_id: str,
        body: SyntheticsGlobalVariable,
    ) -> SyntheticsGlobalVariable:
        """Edit a global variable.

        Edit a Synthetics global variable.

        :param variable_id: The ID of the global variable.
        :type variable_id: str
        :param body: Details of the global variable to update.
        :type body: SyntheticsGlobalVariable
        :rtype: SyntheticsGlobalVariable
        """
        kwargs: Dict[str, Any] = {}
        kwargs["variable_id"] = variable_id

        kwargs["body"] = body

        return self._edit_global_variable_endpoint.call_with_http_info(**kwargs)

    def get_api_test(
        self,
        public_id: str,
    ) -> SyntheticsAPITest:
        """Get an API test.

        Get the detailed configuration associated with
        a Synthetic API test.

        :param public_id: The public ID of the test to get details from.
        :type public_id: str
        :rtype: SyntheticsAPITest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        return self._get_api_test_endpoint.call_with_http_info(**kwargs)

    def get_api_test_latest_results(
        self,
        public_id: str,
        *,
        from_ts: Union[int, UnsetType] = unset,
        to_ts: Union[int, UnsetType] = unset,
        probe_dc: Union[List[str], UnsetType] = unset,
    ) -> SyntheticsGetAPITestLatestResultsResponse:
        """Get an API test's latest results summaries.

        Get the last 50 test results summaries for a given Synthetics API test.

        :param public_id: The public ID of the test for which to search results for.
        :type public_id: str
        :param from_ts: Timestamp in milliseconds from which to start querying results.
        :type from_ts: int, optional
        :param to_ts: Timestamp in milliseconds up to which to query results.
        :type to_ts: int, optional
        :param probe_dc: Locations for which to query results.
        :type probe_dc: [str], optional
        :rtype: SyntheticsGetAPITestLatestResultsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        if from_ts is not unset:
            kwargs["from_ts"] = from_ts

        if to_ts is not unset:
            kwargs["to_ts"] = to_ts

        if probe_dc is not unset:
            kwargs["probe_dc"] = probe_dc

        return self._get_api_test_latest_results_endpoint.call_with_http_info(**kwargs)

    def get_api_test_result(
        self,
        public_id: str,
        result_id: str,
    ) -> SyntheticsAPITestResultFull:
        """Get an API test result.

        Get a specific full result from a given (API) Synthetic test.

        :param public_id: The public ID of the API test to which the target result belongs.
        :type public_id: str
        :param result_id: The ID of the result to get.
        :type result_id: str
        :rtype: SyntheticsAPITestResultFull
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["result_id"] = result_id

        return self._get_api_test_result_endpoint.call_with_http_info(**kwargs)

    def get_browser_test(
        self,
        public_id: str,
    ) -> SyntheticsBrowserTest:
        """Get a browser test.

        Get the detailed configuration (including steps) associated with
        a Synthetic browser test.

        :param public_id: The public ID of the test to get details from.
        :type public_id: str
        :rtype: SyntheticsBrowserTest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        return self._get_browser_test_endpoint.call_with_http_info(**kwargs)

    def get_browser_test_latest_results(
        self,
        public_id: str,
        *,
        from_ts: Union[int, UnsetType] = unset,
        to_ts: Union[int, UnsetType] = unset,
        probe_dc: Union[List[str], UnsetType] = unset,
    ) -> SyntheticsGetBrowserTestLatestResultsResponse:
        """Get a browser test's latest results summaries.

        Get the last 50 test results summaries for a given Synthetics Browser test.

        :param public_id: The public ID of the browser test for which to search results
            for.
        :type public_id: str
        :param from_ts: Timestamp in milliseconds from which to start querying results.
        :type from_ts: int, optional
        :param to_ts: Timestamp in milliseconds up to which to query results.
        :type to_ts: int, optional
        :param probe_dc: Locations for which to query results.
        :type probe_dc: [str], optional
        :rtype: SyntheticsGetBrowserTestLatestResultsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        if from_ts is not unset:
            kwargs["from_ts"] = from_ts

        if to_ts is not unset:
            kwargs["to_ts"] = to_ts

        if probe_dc is not unset:
            kwargs["probe_dc"] = probe_dc

        return self._get_browser_test_latest_results_endpoint.call_with_http_info(**kwargs)

    def get_browser_test_result(
        self,
        public_id: str,
        result_id: str,
    ) -> SyntheticsBrowserTestResultFull:
        """Get a browser test result.

        Get a specific full result from a given (browser) Synthetic test.

        :param public_id: The public ID of the browser test to which the target result
            belongs.
        :type public_id: str
        :param result_id: The ID of the result to get.
        :type result_id: str
        :rtype: SyntheticsBrowserTestResultFull
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["result_id"] = result_id

        return self._get_browser_test_result_endpoint.call_with_http_info(**kwargs)

    def get_global_variable(
        self,
        variable_id: str,
    ) -> SyntheticsGlobalVariable:
        """Get a global variable.

        Get the detailed configuration of a global variable.

        :param variable_id: The ID of the global variable.
        :type variable_id: str
        :rtype: SyntheticsGlobalVariable
        """
        kwargs: Dict[str, Any] = {}
        kwargs["variable_id"] = variable_id

        return self._get_global_variable_endpoint.call_with_http_info(**kwargs)

    def get_private_location(
        self,
        location_id: str,
    ) -> SyntheticsPrivateLocation:
        """Get a private location.

        Get a Synthetics private location.

        :param location_id: The ID of the private location.
        :type location_id: str
        :rtype: SyntheticsPrivateLocation
        """
        kwargs: Dict[str, Any] = {}
        kwargs["location_id"] = location_id

        return self._get_private_location_endpoint.call_with_http_info(**kwargs)

    def get_synthetics_ci_batch(
        self,
        batch_id: str,
    ) -> SyntheticsBatchDetails:
        """Get details of batch.

        Get a batch's updated details.

        :param batch_id: The ID of the batch.
        :type batch_id: str
        :rtype: SyntheticsBatchDetails
        """
        kwargs: Dict[str, Any] = {}
        kwargs["batch_id"] = batch_id

        return self._get_synthetics_ci_batch_endpoint.call_with_http_info(**kwargs)

    def get_test(
        self,
        public_id: str,
    ) -> SyntheticsTestDetails:
        """Get a test configuration.

        Get the detailed configuration associated with a Synthetics test.

        :param public_id: The public ID of the test to get details from.
        :type public_id: str
        :rtype: SyntheticsTestDetails
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        return self._get_test_endpoint.call_with_http_info(**kwargs)

    def list_global_variables(
        self,
    ) -> SyntheticsListGlobalVariablesResponse:
        """Get all global variables.

        Get the list of all Synthetics global variables.

        :rtype: SyntheticsListGlobalVariablesResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_global_variables_endpoint.call_with_http_info(**kwargs)

    def list_locations(
        self,
    ) -> SyntheticsLocations:
        """Get all locations (public and private).

        Get the list of public and private locations available for Synthetic
        tests. No arguments required.

        :rtype: SyntheticsLocations
        """
        kwargs: Dict[str, Any] = {}
        return self._list_locations_endpoint.call_with_http_info(**kwargs)

    def list_tests(
        self,
        *,
        page_size: Union[str, UnsetType] = unset,
        page_number: Union[str, UnsetType] = unset,
    ) -> SyntheticsListTestsResponse:
        """Get the list of all Synthetic tests.

        Get the list of all Synthetic tests.

        :param page_size: Used for pagination. The number of tests returned in the page.
        :type page_size: str, optional
        :param page_number: Used for pagination. Which page you want to retrieve. Starts at zero.
        :type page_number: str, optional
        :rtype: SyntheticsListTestsResponse
        """
        kwargs: Dict[str, Any] = {}
        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_number is not unset:
            kwargs["page_number"] = page_number

        return self._list_tests_endpoint.call_with_http_info(**kwargs)

    def trigger_ci_tests(
        self,
        body: SyntheticsCITestBody,
    ) -> SyntheticsTriggerCITestsResponse:
        """Trigger tests from CI/CD pipelines.

        Trigger a set of Synthetics tests for continuous integration.

        :param body: Details of the test to trigger.
        :type body: SyntheticsCITestBody
        :rtype: SyntheticsTriggerCITestsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._trigger_ci_tests_endpoint.call_with_http_info(**kwargs)

    def trigger_tests(
        self,
        body: SyntheticsTriggerBody,
    ) -> SyntheticsTriggerCITestsResponse:
        """Trigger Synthetics tests.

        Trigger a set of Synthetics tests.

        :param body: The identifiers of the tests to trigger.
        :type body: SyntheticsTriggerBody
        :rtype: SyntheticsTriggerCITestsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._trigger_tests_endpoint.call_with_http_info(**kwargs)

    def update_api_test(
        self,
        public_id: str,
        body: SyntheticsAPITest,
    ) -> SyntheticsAPITest:
        """Edit an API test.

        Edit the configuration of a Synthetic API test.

        :param public_id: The public ID of the test to get details from.
        :type public_id: str
        :param body: New test details to be saved.
        :type body: SyntheticsAPITest
        :rtype: SyntheticsAPITest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["body"] = body

        return self._update_api_test_endpoint.call_with_http_info(**kwargs)

    def update_browser_test(
        self,
        public_id: str,
        body: SyntheticsBrowserTest,
    ) -> SyntheticsBrowserTest:
        """Edit a browser test.

        Edit the configuration of a Synthetic browser test.

        :param public_id: The public ID of the test to get details from.
        :type public_id: str
        :param body: New test details to be saved.
        :type body: SyntheticsBrowserTest
        :rtype: SyntheticsBrowserTest
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["body"] = body

        return self._update_browser_test_endpoint.call_with_http_info(**kwargs)

    def update_private_location(
        self,
        location_id: str,
        body: SyntheticsPrivateLocation,
    ) -> SyntheticsPrivateLocation:
        """Edit a private location.

        Edit a Synthetics private location.

        :param location_id: The ID of the private location.
        :type location_id: str
        :param body: Details of the private location to be updated.
        :type body: SyntheticsPrivateLocation
        :rtype: SyntheticsPrivateLocation
        """
        kwargs: Dict[str, Any] = {}
        kwargs["location_id"] = location_id

        kwargs["body"] = body

        return self._update_private_location_endpoint.call_with_http_info(**kwargs)

    def update_test_pause_status(
        self,
        public_id: str,
        body: SyntheticsUpdateTestPauseStatusPayload,
    ) -> bool:
        """Pause or start a test.

        Pause or start a Synthetics test by changing the status.

        :param public_id: The public ID of the Synthetic test to update.
        :type public_id: str
        :param body: Status to set the given Synthetic test to.
        :type body: SyntheticsUpdateTestPauseStatusPayload
        :rtype: bool
        """
        kwargs: Dict[str, Any] = {}
        kwargs["public_id"] = public_id

        kwargs["body"] = body

        return self._update_test_pause_status_endpoint.call_with_http_info(**kwargs)



"""
Create a Cloud Workload Security Agent rule returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_attributes import (
    CloudWorkloadSecurityAgentRuleCreateAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_data import (
    CloudWorkloadSecurityAgentRuleCreateData,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_request import (
    CloudWorkloadSecurityAgentRuleCreateRequest,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_type import CloudWorkloadSecurityAgentRuleType

body = CloudWorkloadSecurityAgentRuleCreateRequest(
    data=CloudWorkloadSecurityAgentRuleCreateData(
        attributes=CloudWorkloadSecurityAgentRuleCreateAttributes(
            description="Test Agent rule",
            enabled=True,
            expression='exec.file.name == "sh"',
            name="examplecreateacloudworkloadsecurityagentrulereturnsokresponse",
        ),
        type=CloudWorkloadSecurityAgentRuleType.AGENT_RULE,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CloudWorkloadSecurityApi(api_client)
    response = api_instance.create_cloud_workload_security_agent_rule(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class SyntheticsBasicAuth(ModelComposed):
    def __init__(self, **kwargs):
        """
        Object to handle basic authentication when performing the test.

        :param password: Password to use for the basic authentication.
        :type password: str

        :param type: The type of basic authentication to use when performing the test.
        :type type: SyntheticsBasicAuthWebType, optional

        :param username: Username to use for the basic authentication.
        :type username: str

        :param access_key: Access key for the `SIGV4` authentication.
        :type access_key: str

        :param region: Region for the `SIGV4` authentication.
        :type region: str, optional

        :param secret_key: Secret key for the `SIGV4` authentication.
        :type secret_key: str

        :param service_name: Service name for the `SIGV4` authentication.
        :type service_name: str, optional

        :param session_token: Session token for the `SIGV4` authentication.
        :type session_token: str, optional

        :param domain: Domain for the authentication to use when performing the test.
        :type domain: str, optional

        :param workstation: Workstation for the authentication to use when performing the test.
        :type workstation: str, optional

        :param access_token_url: Access token URL to use when performing the authentication.
        :type access_token_url: str

        :param audience: Audience to use when performing the authentication.
        :type audience: str, optional

        :param client_id: Client ID to use when performing the authentication.
        :type client_id: str

        :param client_secret: Client secret to use when performing the authentication.
        :type client_secret: str

        :param resource: Resource to use when performing the authentication.
        :type resource: str, optional

        :param scope: Scope to use when performing the authentication.
        :type scope: str, optional

        :param token_api_authentication: Type of token to use when performing the authentication.
        :type token_api_authentication: SyntheticsBasicAuthOauthTokenApiAuthentication
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
        from datadog_api_client.v1.model.synthetics_basic_auth_sigv4 import SyntheticsBasicAuthSigv4
        from datadog_api_client.v1.model.synthetics_basic_auth_ntlm import SyntheticsBasicAuthNTLM
        from datadog_api_client.v1.model.synthetics_basic_auth_digest import SyntheticsBasicAuthDigest
        from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
        from datadog_api_client.v1.model.synthetics_basic_auth_oauth_rop import SyntheticsBasicAuthOauthROP

        return {
            "oneOf": [
                SyntheticsBasicAuthWeb,
                SyntheticsBasicAuthSigv4,
                SyntheticsBasicAuthNTLM,
                SyntheticsBasicAuthDigest,
                SyntheticsBasicAuthOauthClient,
                SyntheticsBasicAuthOauthROP,
            ],
        }



"""
Submit distribution points returns "Payload accepted" response
"""

from datetime import datetime
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.metrics_api import MetricsApi
from datadog_api_client.v1.model.distribution_point import DistributionPoint
from datadog_api_client.v1.model.distribution_points_payload import DistributionPointsPayload
from datadog_api_client.v1.model.distribution_points_series import DistributionPointsSeries

body = DistributionPointsPayload(
    series=[
        DistributionPointsSeries(
            metric="system.load.1.dist",
            points=[
                DistributionPoint(
                    [
                        datetime.now().timestamp(),
                        [1.0, 2.0],
                    ]
                ),
            ],
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.submit_distribution_points(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.service_definition_v2_link_type import ServiceDefinitionV2LinkType


class ServiceDefinitionV2Link(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.service_definition_v2_link_type import ServiceDefinitionV2LinkType

        return {
            "name": (str,),
            "type": (ServiceDefinitionV2LinkType,),
            "url": (str,),
        }

    attribute_map = {
        "name": "name",
        "type": "type",
        "url": "url",
    }

    def __init__(self_, name: str, type: ServiceDefinitionV2LinkType, url: str, **kwargs):
        """
        Service's external links.

        :param name: Link name.
        :type name: str

        :param type: Link type.
        :type type: ServiceDefinitionV2LinkType

        :param url: Link URL.
        :type url: str
        """
        super().__init__(kwargs)

        self_.name = name
        self_.type = type
        self_.url = url



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_aggregation_function import LogsAggregationFunction
    from datadog_api_client.v2.model.logs_sort_order import LogsSortOrder
    from datadog_api_client.v2.model.logs_aggregate_sort_type import LogsAggregateSortType


class LogsAggregateSort(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_aggregation_function import LogsAggregationFunction
        from datadog_api_client.v2.model.logs_sort_order import LogsSortOrder
        from datadog_api_client.v2.model.logs_aggregate_sort_type import LogsAggregateSortType

        return {
            "aggregation": (LogsAggregationFunction,),
            "metric": (str,),
            "order": (LogsSortOrder,),
            "type": (LogsAggregateSortType,),
        }

    attribute_map = {
        "aggregation": "aggregation",
        "metric": "metric",
        "order": "order",
        "type": "type",
    }

    def __init__(
        self_,
        aggregation: Union[LogsAggregationFunction, UnsetType] = unset,
        metric: Union[str, UnsetType] = unset,
        order: Union[LogsSortOrder, UnsetType] = unset,
        type: Union[LogsAggregateSortType, UnsetType] = unset,
        **kwargs,
    ):
        """
        A sort rule

        :param aggregation: An aggregation function
        :type aggregation: LogsAggregationFunction, optional

        :param metric: The metric to sort by (only used for ``type=measure`` )
        :type metric: str, optional

        :param order: The order to use, ascending or descending
        :type order: LogsSortOrder, optional

        :param type: The type of sorting algorithm
        :type type: LogsAggregateSortType, optional
        """
        if aggregation is not unset:
            kwargs["aggregation"] = aggregation
        if metric is not unset:
            kwargs["metric"] = metric
        if order is not unset:
            kwargs["order"] = order
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)
